@@ -17,7 +17,7 @@ using namespace Snore;
 bool SnoreToast::isReady()
 {
     if (errorString().isEmpty() && QSysInfo::windowsVersion() < QSysInfo::WV_WINDOWS8) {
-        setErrorString(name() + tr(" needs at least Windows 8 to run."));
+        setErrorString(tr("%1 needs at least Windows 8 to run.").arg(name()));
         return false;
     }
     return true;
@@ -36,12 +36,10 @@ void SnoreToast::slotNotify(Notification notification)
     arguements << QLatin1String("-t")
                << notification.title()
                << QLatin1String("-m")
-               << notification.text();
-    if (notification.icon().isValid()) {
-        arguements << QLatin1String("-p")
-                   << QDir::toNativeSeparators(notification.icon().localUrl());
-    }
-    arguements << QLatin1String("-w")
+               << notification.text()
+               << QLatin1String("-p")
+               << QDir::toNativeSeparators(notification.icon().localUrl(QSize(1024, 1024)))
+               << QLatin1String("-w")
                << QLatin1String("-appID")
                << appId(notification.application())
                << QLatin1String("-id")
@@ -82,8 +80,8 @@ void SnoreToast::slotNotify(Notification notification)
 
 void SnoreToast::slotRegisterApplication(const Application &application)
 {
-    if (!application.constHints().contains("windows_app_id")) {
-
+    if (!application.constHints().contains("windows-app-id")) {
+        snoreDebug(SNORE_INFO) << "No windows-app-id found in hints. Installing default shortcut with appID.";
         QProcess *p = createProcess(Notification());
         QStringList arguements;
         arguements << QLatin1String("-install")
@@ -109,9 +107,6 @@ void SnoreToast::slotCloseNotification(Notification notification)
 QString SnoreToast::appId(const Application &application)
 {
     QString appID = application.constHints().value("windows-app-id").toString();
-    if (appID.isEmpty()) {
-        appID = application.constHints().value("windows_app_id").toString();
-    }
     if (appID.isEmpty()) {
         appID = QString(qApp->organizationName() + QLatin1Char('.') + qApp->applicationName() + QLatin1String(".SnoreToast")).remove(QLatin1Char(' '));
     }
