@@ -1,6 +1,6 @@
 /*
     SnoreNotify is a Notification Framework based on Qt
-    Copyright (C) 2013-2014  Patrick von Reth <vonreth@kde.org>
+    Copyright (C) 2013-2015  Hannah von Reth <vonreth@kde.org>
 
     SnoreNotify is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -135,7 +135,7 @@ void PushoverFrontend::connectToService()
     snoreDebug(SNORE_DEBUG) << "Connecting ton service";
     m_socket = new QWebSocket(QString(), QWebSocketProtocol::VersionLatest, this);
 
-    connect(m_socket, &QWebSocket::binaryMessageReceived, [&](const QByteArray & msg) {
+    connect(m_socket.data(), &QWebSocket::binaryMessageReceived, [&](const QByteArray & msg) {
         char c = msg.at(0);
         switch (c) {
         case '#':
@@ -158,18 +158,19 @@ void PushoverFrontend::connectToService()
             m_socket->deleteLater();
             break;
         default:
-            snoreDebug(SNORE_WARNING) << "unknown message recieved" << msg;
+            snoreDebug(SNORE_WARNING) << "unknown message received" << msg;
         }
     });
-    connect(m_socket, &QWebSocket::disconnected, [this]() {
+    connect(m_socket.data(), &QWebSocket::disconnected, [this]() {
         snoreDebug(SNORE_WARNING) << "disconnected";
-        QTimer::singleShot(500, this, &PushoverFrontend::connectToService);
+        //TODO: use new style connect once we depend on qt 5.4
+        QTimer::singleShot(500, this, SLOT(PushoverFrontend::connectToService()));
     });
-    connect(m_socket, static_cast<void (QWebSocket::*)(QAbstractSocket::SocketError)>(&QWebSocket::error), [&](QAbstractSocket::SocketError error) {
+    connect(m_socket.data(), static_cast<void (QWebSocket::*)(QAbstractSocket::SocketError)>(&QWebSocket::error), [&](QAbstractSocket::SocketError error) {
         snoreDebug(SNORE_WARNING) << error << m_socket->errorString();
         emit loggedInChanged(false);
     });
-    connect(m_socket, &QWebSocket::connected, [&]() {
+    connect(m_socket.data(), &QWebSocket::connected, [&]() {
         snoreDebug(SNORE_DEBUG) << "connecting";
         m_socket->sendBinaryMessage((QLatin1String("login:") + device() + QLatin1Char(':') + secret() + QLatin1Char('\n')).toUtf8().constData());
         emit loggedInChanged(true);
@@ -241,9 +242,9 @@ void PushoverFrontend::getMessages()
                 Application app = SnoreCore::instance().aplications().value(appName);
 
                 if (!app.isValid()) {
-                    Icon icon(QLatin1String("https://api.pushover.net/icons/") +
-                              notification.value(QLatin1String("icon")).toString() +
-                              QLatin1String(".png"));
+                    Icon icon(Icon::fromWebUrl(QUrl::fromEncoded((QLatin1String("https://api.pushover.net/icons/") +
+                                               notification.value(QLatin1String("icon")).toString() +
+                                               QLatin1String(".png")).toUtf8().constData())));
                     app = Application(appName, icon);
                     SnoreCore::instance().registerApplication(app);
                 }
