@@ -1,6 +1,6 @@
 /*
     SnoreNotify is a Notification Framework based on Qt
-    Copyright (C) 2015  Patrick von Reth <vonreth@kde.org>
+    Copyright (C) 2015  Hannah von Reth <vonreth@kde.org>
 
     SnoreNotify is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -33,7 +33,7 @@ SoundSettings::SoundSettings(SnorePlugin *snorePlugin, QWidget *parent) :
     m_spinBoxVolume->setRange(0, 100);
     addRow(tr("Volume:"), m_spinBoxVolume);
 
-    addRow(tr("Audio file:"), m_lineEditFileName, tr("The sound played when a notifications is recieved."));
+    addRow(tr("Audio file:"), m_lineEditFileName, tr("The sound played when a notification is received."));
     QPushButton *button = new QPushButton(tr("Select a audio file"));
     connect(button, &QPushButton::clicked, [this]() {
         QFileDialog dialog;
