@@ -1,6 +1,6 @@
 /*
     SnoreNotify is a Notification Framework based on Qt
-    Copyright (C) 2015  Patrick von Reth <vonreth@kde.org>
+    Copyright (C) 2015  Hannah von Reth <vonreth@kde.org>
 
     SnoreNotify is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -26,18 +26,33 @@
 #include <QApplication>
 #include <QDialogButtonBox>
 
+#include <iostream>
+
 using namespace Snore;
 
-SettingsWindow::SettingsWindow(QWidget *parent) :
+SettingsWindow::SettingsWindow(const QString &appName, QWidget *parent) :
     QMainWindow(parent),
     ui(new Ui::SettingsWindow)
 {
     ui->setupUi(this);
     ui->widget->show();
 
-    QStringList list = knownApps();
-    list.removeAll(qApp->applicationName());
-    ui->comboBox->addItems(list);
+    if (appName == QLatin1String("global")) {
+        QStringList list = knownApps();
+        list.removeAll(qApp->applicationName());
+        ui->comboBox->addItems(list);
+    } else {
+        if (!knownApps().contains(appName)) {
+            std::wcerr << "Error: " << appName.toUtf8().constData() << " is not known to Snorenotify" << std::endl;
+            exit(1);
+        }
+        ui->comboBox->deleteLater();
+        ui->label->deleteLater();
+        SnoreCorePrivate::instance()->setLocalSttingsPrefix(appName);
+        setWindowTitle(tr("%1 Settings").arg(appName));
+        ui->widget->initTabs();
+        ui->widget->setVisible(true);
+    }
 }
 
 SettingsWindow::~SettingsWindow()
@@ -70,6 +85,7 @@ void SettingsWindow::on_buttonBox_clicked(QAbstractButton *button)
     switch (ui->buttonBox->buttonRole(button)) {
     case QDialogButtonBox::AcceptRole:
         ui->widget->accept();
+        qApp->processEvents();
         qApp->quit();
         break;
     case QDialogButtonBox::ApplyRole:
