@@ -1,6 +1,6 @@
 /*
     SnoreNotify is a Notification Framework based on Qt
-    Copyright (C) 2014-2015  Patrick von Reth <vonreth@kde.org>
+    Copyright (C) 2014-2015  Hannah von Reth <vonreth@kde.org>
 
     SnoreNotify is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published by
@@ -93,10 +93,10 @@ int main(int argc, char *argv[])
     QCommandLineOption alertName(QStringList() << QLatin1String("c") << QLatin1String("alert"), QLatin1String("Set the notification alert class."), QLatin1String("alert"), QLatin1String("Default"));
     parser.addOption(alertName);
 
-    QCommandLineOption iconPath(QStringList() << QLatin1String("i") << QLatin1String("icon"), QLatin1String("Set the notification icon."), QLatin1String("icon"), QLatin1String(":/root/snore.png"));
+    QCommandLineOption iconPath(QStringList() << QLatin1String("i") << QLatin1String("icon"), QLatin1String("Set the notification icon."), QLatin1String("icon"));
     parser.addOption(iconPath);
 
-    QCommandLineOption priority(QStringList() << QLatin1String("p") << QLatin1String("priority"), QLatin1String("Set the notification's' priority."), QLatin1String("[-2, 2]"), QLatin1String("0"));
+    QCommandLineOption priority(QStringList() << QLatin1String("p") << QLatin1String("priority"), QLatin1String("Set the notification's priority."), QLatin1String("[-2, 2]"), QLatin1String("0"));
     parser.addOption(priority);
 
     QCommandLineOption markup(QStringList() << QLatin1String("markup"), QLatin1String("Enable markup support."), QLatin1String("[0,1]"), QLatin1String("0"));
@@ -118,7 +118,10 @@ int main(int argc, char *argv[])
 
         core.loadPlugins(SnorePlugin::BACKEND | SnorePlugin::SECONDARY_BACKEND);
 
-        Icon icon(parser.value(iconPath));
+        Icon icon = Icon::defaultIcon();
+        if (parser.isSet(iconPath)) {
+            icon = Icon(parser.value(iconPath));
+        }
         Application application(parser.value(applicationName), icon);
         Alert alert(parser.value(alertName), icon);
         application.addAlert(alert);
